# Info 
[i4i](https://aws.amazon.com/ec2/instance-types/i4i/):
- I4i instances are powered by the latest generation Intel Xeon Scalable (Ice Lake) Processors with an all-core turbo frequency of 3.5 GHz.


---
## History
1. [link](https://www.cpubenchmark.net/cpu.php?cpu=Intel+Xeon+Platinum+8375C+%40+2.90GHz&id=4486)